@@ -26,6 +26,15 @@ class ssh():
         except:
             print("Problem SCP")
 
+    def scpr(self):
+        try:
+            self.wait()
+            os.system('scp -i %s -o StrictHostKeyChecking=no '
+                      '-o UserKnownHostsFile=/dev/null -r %s %s@%s: > /dev/null 2>&1'
+                      % (self.key, self.file, self.username, self.host))
+        except:
+            print("Problem SCP")
+
     def connect(self):
         try:
             self.wait()
