@@ -18,7 +18,7 @@ class kubernetes:
         api = str((kubmaster+':8080'))
         self.kubmaster = kubmaster
         self.connect = K8sConfig(api_host=api)
-        self.key = '~/Dropbox/python/key/id_rsa'
+        self.key = '~/Dropbox/id_rsa'
         self.user = 'administrator'
         self.dir = '~/Dropbox/python/pykubernetes'
 
@@ -80,7 +80,7 @@ class kubernetes:
 
     def scale_deployment(self, name, replicas):
         exe = ssh(self.user, self.key, self.kubmaster,
-                  cmd='sudo kubectl scale --replicas=%s deployment/%s-deployment > /tmp/bla 2>&1'
+                  cmd='sudo kubectl scale --replicas=%s deployment/%s > /tmp/bla 2>&1'
                       % (int(replicas), name))
         exe.connect()
 
@@ -90,3 +90,21 @@ class kubernetes:
                       '--external-ip=%s --name=%s > /tmp/bla 2>&1' % (service, label_name,
                                                                       port, targe_port, type, external, name))
         exe.connect()
+
+    def create_wordpress(self, name, replicas=None):
+        if not replicas:
+            exe = ssh(self.user, self.key, self.kubmaster,
+                      cmd='kubectl run %s --image=tutum/wordpress --port=80 > /tmp/bla 2>&1' % name)
+            exe.connect()
+        else:
+            exe = ssh(self.user, self.key, self.kubmaster,
+                      cmd='kubectl run %s --image=tutum/wordpress --port=80 --replicas=%s> /tmp/bla 2>&1'
+                          % (name, int(replicas)))
+            exe.connect()
+
+    def create_cluster_wordpress(self):
+        exe = ssh(self.user, self.key, self.kubmaster,
+                  arq='%s/pods/wordpress-apache2-mysql' % self.dir,
+                  cmd='cd wordpress-apache2-mysql && sudo bash -x install.sh > /tmp/bla 2>&1')
+        exe.scpr()
+        exe.connect()
